<?php

namespace Bixo\Order\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Order\Actions\OrderItemsAction;
use Bixo\Order\Http\Requests\OrderItemsActionRequest;
use Bixo\Order\Http\Resources\OrderItemsResource;
use Bixo\Order\Models\OrderItems;

/**
 * Admin web controller class.
 */
class OrderItemsActionController extends BaseController
{

    /**
     * Action controller function for order_items.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OrderItemsActionRequest $request, OrderItems $order_items, $action)
    {
        try {
            $request = $request->all();
            $order_items = OrderItemsAction::run($action, $order_items, $request);

            $data = new OrderItemsResource($order_items);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('order::order_items.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('order/order_items/' . $order_items->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('order/order_items/' . $order_items->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
