<?php

namespace Bixo\Order\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Order\Http\Resources\OrderResource;
use Bixo\Order\Http\Resources\OrdersCollection;
use Bixo\Order\Scopes\OrderItemsPublicScope;
use Bixo\Order\Models\OrderItems;

class OrderItemsPublicController extends BaseController
{

    /**
     * Show order_items's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = OrderItems::pushScope(new RequestScope())
            ->pushScope(new OrderItemsPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $order_items = new OrderItemsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('order::order_items.names'))
            ->view('order::public.order_items.index')
            ->data(compact('order_items', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show order_items.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = OrderItems::findBySlug($slug);
        $data = new OrderItemsResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('order::order_items.name'))
            ->view('order::public.order_items.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
