<?php

namespace Bixo\Order\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Order\Forms\OrderItems as OrderItemsForm;
use Bixo\Order\Http\Requests\OrderItemsResourceRequest;
use Bixo\Order\Http\Resources\OrderItemsResource;
use Bixo\Order\Http\Resources\OrderItemsCollection;
use Bixo\Order\Models\OrderItems;
use Bixo\Order\Actions\OrderItemsAction;
use Bixo\Order\Actions\OrderItemsActions;


/**
 * Resource controller class for order_items.
 */
class OrderItemsResourceController extends BaseController
{

    /**
     * Initialize order_items resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = OrderItemsForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.order.modules'), 'order', guard_url('order'));
            return $next($request);
        });
    }

    /**
     * Display a list of order_items.
     *
     * @return Response
     */
    public function index(OrderItemsResourceRequest $request)
    {
        $request = $request->all();
        $page = OrderItemsActions::run('paginate', $request);

        $data = new OrderItemsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('order::order_items.names'))
            ->view('order::order_items.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display order_items.
     *
     * @param Request $request
     * @param Model   $order_items
     *
     * @return Response
     */
    public function show(OrderItemsResourceRequest $request, OrderItems $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new OrderItemsResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('order::order_items.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('order::order_items.show')
            ->output();
    }

    /**
     * Show the form for creating a new order_items.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OrderItemsResourceRequest $request, OrderItems $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new OrderItemsResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('order::order_items.name'))
            ->view('order::order_items.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new order_items.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrderItemsResourceRequest $request, OrderItems $model)
    {
        try {
            $request = $request->all();
            $model = OrderItemsAction::run('store', $model, $request);
            $data = new OrderItemsResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('order::order_items.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('order/order_items/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/order/order_items'))
                ->redirect();
        }

    }

    /**
     * Show order_items for editing.
     *
     * @param Request $request
     * @param Model   $order_items
     *
     * @return Response
     */
    public function edit(OrderItemsResourceRequest $request, OrderItems $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new OrderItemsResource($model);
        // return view('order::order_items.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('order::order_items.name'))
            ->view('order::order_items.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the order_items.
     *
     * @param Request $request
     * @param Model   $order_items
     *
     * @return Response
     */
    public function update(OrderItemsResourceRequest $request, OrderItems $model)
    {
        try {
            $request = $request->all();
            $model = OrderItemsAction::run('update', $model, $request);
            $data = new OrderItemsResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('order::order_items.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('order/order_items/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('order/order_items/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the order_items.
     *
     * @param Model   $order_items
     *
     * @return Response
     */
    public function destroy(OrderItemsResourceRequest $request, OrderItems $model)
    {
        try {

            $request = $request->all();
            $model = OrderItemsAction::run('destroy', $model, $request);
            $data = new OrderItemsResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('order::order_items.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('order/order_items/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('order/order_items/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
