<?php

namespace Bixo\Order\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Order\Events\OrderAction as OrderActionEvent;
use Bixo\Order\Notifications\OrderAction as OrderActionNotification;
use Litepie\Actions\Concerns\AsAction;

class OrderAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the OrderActionEvent.
     *
     * @param   OrderActionEvent  $event
     * @return mixed
     */
    public function handle(OrderActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $order.
     *
     * @param   OrderActionEvent  $event
     * @return void
     */
    public function create(OrderActionEvent $event)
    {
        $client = $event->order->client;
        Notification::send($client, new OrderActionNotification($event));
    }

    /**
     * Handle the OrderActionEvent as a listener.
     *
     * @param   OrderActionEvent  $event
     * @return mixed
     */
    public function asListener(OrderActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   OrderActionEvent  $event
     * @return bool
     */
    private function isAllowed(OrderActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
