<?php

namespace Bixo\Order\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Order\Events\OrderItemsWorkflow as OrderItemsWorkflowEvent;
use Bixo\Order\Notifications\OrderItemsWorkflow as OrderItemsWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class OrderItemsWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(OrderItemsWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $order_items is submitted.
     *
     * @param OrderItemsWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(OrderItemsWorkflowEvent $event)
    {
        $client = $event->order_items->client;
        Notification::send($client, new OrderItemsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $order_items is published.
     *
     * @param OrderItemsWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(OrderItemsWorkflowEvent $event)
    {
        $client = $event->order_items->client;
        Notification::send($client, new OrderItemsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $order_items is approved.
     *
     * @param OrderItemsWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(OrderItemsWorkflowEvent $event)
    {
        $client = $event->order_items->client;
        Notification::send($client, new OrderItemsWorkflowNotification($event));
    }

    /**
     * Handles the $order_items workflow event as a listener.
     *
     * @param OrderItemsWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(OrderItemsWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
