<?php

namespace Bixo\Order\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Order\Events\OrderWorkflow as OrderWorkflowEvent;
use Bixo\Order\Notifications\OrderWorkflow as OrderWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class OrderWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(OrderWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $order is submitted.
     *
     * @param OrderWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(OrderWorkflowEvent $event)
    {
        $client = $event->order->client;
        Notification::send($client, new OrderWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $order is published.
     *
     * @param OrderWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(OrderWorkflowEvent $event)
    {
        $client = $event->order->client;
        Notification::send($client, new OrderWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $order is approved.
     *
     * @param OrderWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(OrderWorkflowEvent $event)
    {
        $client = $event->order->client;
        Notification::send($client, new OrderWorkflowNotification($event));
    }

    /**
     * Handles the $order workflow event as a listener.
     *
     * @param OrderWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(OrderWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
