<?php
namespace Bixo\Order\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Order\Events\OrderItemsAction as OrderItemsActionEvent;
use Bixo\Order\Models\OrderItems;

class OrderItemsAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $order_items;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param OrderItemsActionEvent $order_items
     */
    public function __construct(OrderItemsActionEvent $order_items)
    {
        $this->action = $event->action;
        $this->order_items = $order_items;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('OrderItems Approved - ' . config('app.name'))
            ->view('order::order_items.email.action', ['data' => $this->order_items]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
