<?php

namespace Bixo\Order\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Order\Models\OrderItems;

class OrderItemsPolicy
{

    use OrderItemsAction;
    use OrderItemsExim;
    use OrderItemsReport;
    use OrderItemsWorkflow;

    /**
     * Determine if the given user can view the order_items.
     *
     * @param Authenticatable $user
     * @param OrderItems $order_items
     *
     * @return bool
     */
    public function view(Authenticatable $user, OrderItems $order_items)
    {
        if ($authUser->canDo('order.order_items.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $order_items->is_owner;
    }

    /**
     * Determine if the given user can create a order_items.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('order.order_items.create');
    }

    /**
     * Determine if the given user can update the given order_items.
     *
     * @param Authenticatable $user
     * @param OrderItems $order_items
     *
     * @return bool
     */
    public function update(Authenticatable $user, OrderItems $order_items)
    {
        if ($user->canDo('order.order_items.edit') && $user->isAdmin()) {
            return true;
        }

        return $order_items->is_owner;
    }

    /**
     * Determine if the given user can delete the given order_items.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, OrderItems $order_items)
    {
        return $order_items->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
