<?php

namespace Bixo\Order\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Order\Models\Order;

class OrderPolicy
{


    /**
     * Determine if the given user can view the order.
     *
     * @param Authenticatable $user
     * @param Order $order
     *
     * @return bool
     */
    public function view(Authenticatable $user, Order $order)
    {
        if ($authUser->canDo('order.order.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $order->is_owner;
    }

    /**
     * Determine if the given user can create a order.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('order.order.create');
    }

    /**
     * Determine if the given user can update the given order.
     *
     * @param Authenticatable $user
     * @param Order $order
     *
     * @return bool
     */
    public function update(Authenticatable $user, Order $order)
    {
        if ($user->canDo('order.order.edit') && $user->isAdmin()) {
            return true;
        }

        return $order->is_owner;
    }

    /**
     * Determine if the given user can delete the given order.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Order $order)
    {
        return $order->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
